*********************
The sherpa.sim module
*********************

.. currentmodule:: sherpa.sim

.. automodule:: sherpa.sim

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      MCMC
      ReSampleData

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      flat
      inverse
      inverse2
      mcmc_to_arviz

Class Inheritance Diagram
=========================

.. inheritance-diagram:: MCMC
   :parts: 1
